package
Version:
v0.0.0-...-849f1c2
Opens a new window with list of versions in this module.
Published: May 30, 2024
License: AGPL-3.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Cache struct {
PullZone int `yaml:"pull_zone"`
AccessKey string `yaml:"access_key"`
}
Cache config
type Config struct {
Path string `yaml:"path"`
Cache Cache `yaml:"cache"`
Storage Storage `yaml:"storage"`
}
Config of the bunny-upload
Read config from file system
type Storage struct {
Zone string `yaml:"storage_zone"`
Password string `yaml:"password"`
}
Storage config
Source Files
¶
Click to show internal directories.
Click to hide internal directories.